People - Ed Sheeran Wants To Set Up Taylor Swift, But We’re Not Sure About His Matchmaking Skills | Fame | The Debrief
Description: Ed Sheeran wants to set taylor Swift up with orlando bloom
Keywords: taylor Swift, orlando bloom, ed sheeran, set up, cupid, love

Lena deCasparis | Contributing Writer | 5 days ago

# Ed Sheeran Wants To Set Up Taylor Swift, But We’re Not So Sure About His Matchmaking Skills

The Debrief: Ed put the cupid bow and arrow down, and stick to playing the guitar

### Share This

So in our eyes Ed Sheeran can do no wrong. He’s the most loveable, adorkable (that’s adorable crossed with dorky FYI) pop star EVER. And we love him, we really do. However when it comes to his matchmaking skills for our fave gal, and his BFF, Taylor Swift – well we think he’s a little bit off.
This week Ed told Now magazine that he hoped he could set up Taylor with none other that Orlando Bloom. He said ‘He’s lovely, and they live in the same building. [I'm hoping that] the magic might present itself eventually.’
Er, we’re not so sure.

Now don’t get us wrong we’ve had a soft spot for floppy haired Mr Bloom since his Pirate days, and when he took a swing at Bieber earlier this year well we know which side of the ring we were on.

But is he worthy of all that is T-Swift? The jury is out. And let’s not forget Bloom's also already dated Taylor’s BFF Selena, we predict that might make this matchmake very unlikely as Taylor is 100% 'Sisters Before Misters'.

Ultimately we think Tay can do better, but then we're not sure there is any man who is worthy!

Like this? You might also be interested in:

Lena Dunham Has Declared Today Taylor Swift Day. Here’s Why We All Need To Get Better At Celebrating Female Success

South Park Does A Lorde Skit. But Who’s It Taking The Piss Out Of?

Lorde Gave Taylor Swift The First Listen To Her New Song

Follow Lena on Twitter: @Lenadecasparis

Pictures: Getty

Tags: Taylor Swift, Ed Sheeran

At work? With your gran?

You might want to think about the fact you're about to read something that wouldn't exactly get a PG rating

### Share This

### Comments

The Debrief chat powered by DISQUS Read more

#### Disqus

Disqus allows you to post comments on our site. You can only post comments if you register with Disqus and your registration data will be handled in accordance with their privacy policy.

Disqus will use your registration data (email) to send you additional information. Details of how you can opt out are contained in the verification email which you will be sent after you sign up

Please read the Disqus terms of service

Loading...

comments powered by Disqus

## Need a change of scene?

### Staying In

#### Life Lessons From TED Talks In 2014

### Staying In

#### 2014 In Food: The Good, The Bad, The Absolutely Bloody Weird

### Getting Ready

#### Here Are A Few Very Helpful Hacks For Looking Affter Your Clothes This Winter

## Sign UpNow

For exclusive news, reviews, ace competitions and discounts, sign up for our email. It'll make your inbox great. Guaranteed.

Get The Debrief

## We reckon you’ll also want to read

### Fame

#### Taylor Swift's Getting Her Own Floor At The Grammy Museum

### Fame

#### Lose Your Lunchtime To This Really Rather Adorable Video Of The Victoria's Secret Angels Lip Syncing To Taylor Swift

### Fame

#### So This Is What It’s Actually Like To Be Taylor Swift’s Best Mate

### People

#### In Which We Discuss Whether Taylor's Or Beyonce's Lyrics Are Better Break-Up Material

### Fame

#### Zayn's Hair & Chris Martin's Blue Peter Badge: Here's A Few Observations From The Band Aid 30 Video

### Fame

#### Miley Cyrus And Ed Sheeran Have Beef, But Only Miley Has Pork

## Join Us Elsewhere

## Join Us OnPinterest